@@ -1,11 +1,11 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
-;;; Copyright © 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024 Janneke Nieuwenhuizen <janneke@gnu.org>
-;;; Copyright © 2014, 2018, 2020, 2021, 2022, 2023 Rutger van Beusekom <rutger@dezyne.org>
+;;; Copyright © 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024, 2025 Janneke Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2014, 2018, 2020, 2021, 2022, 2023, 2024 Rutger (regtur) van Beusekom <rutger@dezyne.org>
 ;;; Copyright © 2017, 2018, 2019, 2020 Rob Wieringa <rma.wieringa@gmail.com>
 ;;; Copyright © 2017, 2018, 2020 Johri van Eerd <vaneerd.johri@gmail.com>
 ;;; Copyright © 2018 Filip Toman <filip.toman@verum.com>
-;;; Copyright © 2019, 2020, 2022, 2023 Paul Hoogendijk <paul@dezyne.org>
+;;; Copyright © 2019, 2020, 2022, 2023, 2024 Paul Hoogendijk <paul@dezyne.org>
 ;;;
 ;;; This file is part of Dezyne.
 ;;;
@@ -35,13 +35,15 @@
   #:use-module (ice-9 q)
 
   #:use-module (dzn ast accessor)
-  #:use-module (dzn ast goops)
+  #:use-module (dzn ast ast)
   #:use-module (dzn ast equal)
   #:use-module (dzn ast lookup)
   #:use-module (dzn ast util)
   #:use-module (dzn misc)
 
-  #:export (ast:argument->formal
+  #:export (ast:add-statement
+            ast:add-statement*
+            ast:argument->formal
             ast:base-name
             ast:blocking?
             ast:continuation*
@@ -143,6 +145,7 @@
                ast:perfect-funcq
                ast:pure-funcq
                ast:node-eq?
+               ast:port-eq?
 
                ast:argument*
                ast:binding*
@@ -204,6 +207,13 @@
          (or (and (null? statements) (is-a? (.parent o) <behavior>))
              (and (pair? statements) ((compose ast:declarative? car) statements))))))
 
+(define-method (ast:declarative? (o <call>))
+  (let ((parent (ast:parent (.parent o) (negate (is? <expression>)))))
+    (or (is-a? parent <invariant>)
+        (and (is-a? parent <guard>)
+             (or (null? (tree-collect (cute ast:eq? <> o) (.statement parent)))
+                 (not (ast:parent parent <on>)))))))
+
 (define (ast:illegal? o)
   (match o
     (($ <declarative-illegal>) o)
@@ -223,6 +233,12 @@
         (and (null? statements) (not (is-a? (.parent o) <behavior>)))
         (and (pair? statements) ((compose ast:imperative? car) statements)))))
 
+(define-method (ast:imperative? (o <call>))
+  (not (ast:declarative? o)))
+
+(define-method (ast:imported? (o <root>))
+  #f)
+
 (define-method (ast:imported? (o <ast>))
   (not (equal? (ast:source-file o) (ast:source-file (ast:parent o <root>)))))
 
@@ -281,7 +297,7 @@
   #t)
 
 (define-method (ast:modeling? (o <trigger>))
-  ((compose ast:modeling? .event) o))
+  ((compose (cute and=> <> ast:modeling?) .event) o))
 
 (define-method (ast:optional? (o <optional>))
   #t)
@@ -379,11 +395,11 @@
 (define-method (ast:event* (o <port>)) ((compose ast:event* .type) o))
 
 (define-method (ast:function* (o <function>))
-  (let* ((calls (tree-collect (is? <call>) o))
+  (let* ((calls (tree-collect (conjoin
+                               (is? <call>)
+                               (negate (cute ast:parent <> <defer>))) o))
          (functions (filter-map .function calls)))
-    (delete-duplicates
-     functions
-     (lambda (a b) (equal? (.name a) (.name b))))))
+    (delete-duplicates functions ast:name-equal?)))
 
 
 ;;;
@@ -440,6 +456,9 @@
 (define-method (ast:requires-no-injected-port* (o <component-model>))
   (filter (conjoin (negate ast:injected?) ast:requires?) (ast:port* o)))
 
+(define-method (ast:direction (o <event>))
+  (.direction o))
+
 (define-method (ast:direction (o <port>))
   (if (ast:provides? o) 'in
       'out))
@@ -711,7 +730,7 @@
    ((as o <int>)
     (list (make <literal> #:value 0)))))
 
-(define-method (ast:values (o <variable>))
+(define-method (ast:values (o <variable>) void)
   "Enum values include their type.name, the scope.name part of the
 type.name is determined by the context referring to the type, hence the
 overload for variable."
@@ -719,10 +738,13 @@ overload for variable."
    ((as (ast:type o) <enum>)
     (map (cute make <enum-literal> #:type.name (.type.name o) #:field <>)
          (ast:field* (ast:type o))))
-   (else (ast:values (ast:type o)))))
+   (else (ast:values (ast:type o) void))))
+
+(define-method (ast:values (o <variable>))
+  (ast:values o #f))
 
 (define-method (ast:default-value (o <ast>))
-  (match (ast:values o)
+  (match (ast:values o (make <void>))
     ((default rest ...) default)))
 
 (define-method (ast:return-values (o <event>) void)
@@ -1104,3 +1126,31 @@ call steps over the function and returns the next statement."
           (ast:previous-statement p))
          (_ #f)))
       (_ #f))))
+
+(define-method (ast:add-statement (o <compound>) statement)
+  (clone o #:elements `(,@(.elements o) ,statement)))
+
+(define-method (ast:add-statement (o <statement>) statement)
+  (make <compound>
+    #:elements (list o statement)
+    #:location (.location o)))
+
+(define* (ast:add-statement* o statement #:key (location o))
+  (match o
+    (($ <compound>)
+     (let* ((elements (ast:statement* o))
+            (elements (ast:add-statement* elements statement #:location o)))
+       (clone o #:elements elements)))
+    ((h ... t)
+     (append o (list (clone statement #:location (.location (.parent t))))))
+    ((h ...)
+     (append o (list (clone statement #:location (.location location)))))
+    (_
+     (let* ((location (.location o))
+            (statement (clone statement #:location location))
+            (elements (if (is-a? o <skip>) (list statement)
+                          (list o statement)))
+            (compound (make <compound>
+                        #:elements elements
+                        #:location location)))
+       (clone compound #:parent (.parent o))))))
