@@ -31,7 +31,7 @@
   #:use-module (srfi srfi-26)
 
   #:use-module (dzn ast accessor)
-  #:use-module (dzn ast goops)
+  #:use-module (dzn ast ast)
 
   #:export (ast:eq?
             ast:equal?
@@ -89,6 +89,9 @@
 (define-method (ast:name-equal? (a <named>) (b <string>))
   (ast:name-equal? (.name a) b))
 
+(define-method (ast:name-equal? (a <named>) (b <named>))
+  (ast:name-equal? (.name a) (.name b)))
+
 (define-method (ast:name-equal? (b <string>) (a <named>))
   (ast:name-equal? a b))
 
