@@ -1,10 +1,10 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
-;;; Copyright © 2018, 2021, 2022, 2023, 2024 Rutger van Beusekom <rutger@dezyne.org>
+;;; Copyright © 2018, 2021, 2022, 2023, 2024, 2025 Rutger (regtur) van Beusekom <rutger@dezyne.org>
 ;;; Copyright © 2019, 2020 Johri van Eerd <vaneerd.johri@gmail.com>
 ;;; Copyright © 2018, 2019, 2020 Rob Wieringa <rma.wieringa@gmail.com>
-;;; Copyright © 2018, 2019, 2020, 2023 Paul Hoogendijk <paul@dezyne.org>
-;;; Copyright © 2018, 2019, 2020, 2021, 2022, 2023 Janneke Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2018, 2019, 2020, 2023, 2024, 2025 Paul Hoogendijk <paul@dezyne.org>
+;;; Copyright © 2018, 2019, 2020, 2021, 2022, 2023, 2024, 2025 Janneke Nieuwenhuizen <janneke@gnu.org>
 ;;;
 ;;; This file is part of Dezyne.
 ;;;
@@ -35,11 +35,12 @@
 
   #:use-module (dzn ast display)
   #:use-module (dzn ast equal)
-  #:use-module (dzn ast goops)
+  #:use-module (dzn ast ast)
   #:use-module (dzn ast normalize)
   #:use-module (dzn ast util)
   #:use-module (dzn ast)
-  #:use-module (dzn code goops)
+  #:use-module (dzn code ast)
+  #:use-module (dzn code shared)
   #:use-module (dzn code language dzn)
   #:use-module (dzn code scmackerel makreel)
   #:use-module (dzn code util)
@@ -174,7 +175,8 @@
                           (is? <functions>)
                           (is? <function>)
                           (is? <statement>))
-                 (is? <call>) o))
+                 (conjoin (is? <call>) ast:imperative?)
+                 o))
          (calls (reachable calls)))
     calls))
 
@@ -266,7 +268,7 @@
 
 (define-method (makreel:call-continuation*-unmemoized (o <behavior>))
   (let* ((calls (tree-collect (disjoin
-                               (is? <call>)
+                               (conjoin (is? <call>) ast:imperative?)
                                (conjoin
                                 (disjoin (is? <variable>)
                                          (is? <assign>))
@@ -583,7 +585,7 @@
            (makreel:add-state-placeholder rest)))
     (((and (? (is? <action>)) statement) rest ...)
      (cons* statement
-            (make <state>)
+            (make <share-state>)
             (makreel:add-state-placeholder rest)))
     (((and (? (is? <statement>)) statement) rest ...)
      (cons (makreel:add-state-placeholder statement)
@@ -607,11 +609,13 @@ transformations."
                   normalize:state+illegals
                   remove-otherwise
                   makreel:tick-names
-                  add-explicit-temporaries
+                  inline-expression-functions
                   add-defer-end
                   purge-data
-                  ) ast)))
+                  (add-explicit-temporaries))
+                 ast)))
       (when (> (dzn:debugity) 1)
+        (debug "normalized root:")
         (ast:pretty-print root (current-error-port)))
       root)))
 
@@ -677,7 +681,7 @@ transformations."
     (let ((sm (root->scmackerel o)))
       (scmackerel:display sm))))
 
-(define* (ast-> ast #:key dir model)
+(define* (ast-> ast #:key dir empty-files? model verbose?)
   (let* ((root (makreel:normalize ast))
          (init (command-line:get 'init))
          (file-name (code:root-file-name root dir ".mcrl2")))
