@@ -1,8 +1,9 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
-;;; Copyright © 2014, 2015, 2017, 2019, 2020, 2021, 2022, 2023 Janneke Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2014, 2015, 2017, 2019, 2020, 2021, 2022, 2023, 2024, 2025 Janneke Nieuwenhuizen <janneke@gnu.org>
 ;;; Copyright © 2017 Rutger van Beusekom <rutger@dezyne.org>
 ;;; Copyright © 2019 Rob Wieringa <rma.wieringa@gmail.com>
+;;; Copyright © 2025 Paul Hoogendijk <paul@dezyne.org>
 ;;;
 ;;; This file is part of Dezyne.
 ;;;
@@ -33,11 +34,11 @@
 
   #:use-module (scmackerel indent)
 
-  #:use-module (dzn ast goops)
+  #:use-module (dzn ast ast)
   #:use-module (dzn ast)
   #:use-module (dzn ast normalize)
   #:use-module (dzn code)
-  #:use-module (dzn code goops)
+  #:use-module (dzn code ast)
   #:use-module (dzn code language dzn)
   #:use-module (dzn code legacy dzn)
   #:use-module (dzn code legacy code)
@@ -175,6 +176,9 @@
 (define-method (scheme:reply-name (o <bool>))
   '("reply-bool"))
 
+(define-method (scheme:reply-name (o <extern>))
+  '("reply-extern"))
+
 (define-method (scheme:reply-name (o <reply>))
   (scheme:reply-name (ast:type (.expression o))))
 
@@ -226,7 +230,7 @@
          o)))
 
 (define-method (scheme:comment (o <ast>))
-  (scheme:comment (.comment o)))
+  (and=> (.comment o) scheme:comment))
 
 (define-method (code:defer-condition (o <defer>))
   (if (not (or (and=> (.arguments o)(compose null? .elements))
@@ -262,7 +266,7 @@
 ;;; Entry point.
 ;;;
 
-(define* (ast-> root #:key (dir ".") model)
+(define* (ast-> root #:key (dir ".") empty-files? model verbose?)
   "Entry point."
 
   (code:foreign-conflict? root)
