@@ -1,7 +1,7 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
 ;;; Copyright © 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024 Janneke Nieuwenhuizen <janneke@gnu.org>
-;;; Copyright © 2018, 2020, 2021, 2022 Paul Hoogendijk <paul@dezyne.org>
+;;; Copyright © 2018, 2020, 2021, 2022, 2025 Paul Hoogendijk <paul@dezyne.org>
 ;;; Copyright © 2017, 2018, 2021, 2022, 2023 Rutger van Beusekom <rutger@dezyne.org>
 ;;; Copyright © 2017, 2018, 2019 Rob Wieringa <rma.wieringa@gmail.com>
 ;;;
@@ -31,7 +31,7 @@
   #:use-module (ice-9 getopt-long)
   #:use-module (ice-9 regex)
 
-  #:use-module (dzn ast goops)
+  #:use-module (dzn ast ast)
   #:use-module (dzn ast)
   #:use-module (dzn code)
   #:use-module (dzn code language makreel)
@@ -99,17 +99,16 @@ Generate exhaustive set of traces for Dezyne model
          (text (regexp-substitute/global #f "\"tag[()].[^\"]*\"" text 'pre "\"tau\"" 'post)))
     text))
 
-(define (model->lts root model file-name)
-  (let* ((lts (verify-pipeline "aut-weak-trace"
-                               root model))
+(define (model->lts root model)
+  (let* ((lts (verify-pipeline "aut-weak-trace" root model))
          (lts (lts-hide-internal-labels lts)))
     (when (string-null? (string-trim-right lts))
-      (throw 'error "failed to create LTS"))
+      (error "failed to create LTS for ~a\n" (makreel:unticked-dotted-name model)))
     lts))
 
-(define (model->traces options root model file-name)
+(define (model->traces options root model)
   (let* ((verbose? (dzn:command-line:get 'verbose))
-         (lts (model->lts root model file-name))
+         (lts (model->lts root model))
          (provides-ports (if (is-a? model <interface>) '()
                              (ast:provides-port* model)))
          (provides-in (if (is-a? model <component>)
@@ -139,10 +138,12 @@ Generate exhaustive set of traces for Dezyne model
                      provides-in
                      #:verbose? verbose?)))
     (when lts?
-      (if (and output (not (equal? output "-")))
-          (with-output-to-file (string-append output "/" model-name ".aut")
-            (cute display lts))
-          (display lts)))))
+      (let* ((lts (aut-text->lts lts))
+             (lts (prioritize-invariant lts)))
+        (if (and output (not (equal? output "-")))
+            (with-output-to-file (string-append output "/" model-name ".aut")
+              (cute display-lts lts))
+            (display-lts lts))))))
 
 (define (main args)
   (let* ((options (parse-opts args))
@@ -191,4 +192,4 @@ Generate exhaustive set of traces for Dezyne model
                         (not (.behavior model))))
                (error "no model with behavior:" model-name))
               (model
-               (model->traces options root model file-name)))))))
+               (model->traces options root model)))))))
