@@ -1,7 +1,7 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
-;;; Copyright © 2014, 2015, 2016, 2017, 2019, 2021, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
-;;; Copyright © 2014, 2015, 2017, 2020, 2024 Rutger van Beusekom <rutger@dezyne.org>
+;;; Copyright © 2014, 2015, 2016, 2017, 2019, 2021, 2022, 2023, 2024 Janneke Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2014, 2015, 2017, 2020, 2024, 2025 Rutger van Beusekom <rutger@dezyne.org>
 ;;; Copyright © 2019 Rob Wieringa <rma.wieringa@gmail.com>
 ;;;
 ;;; This file is part of Dezyne.
@@ -21,6 +21,8 @@
 
 (define-module (dzn misc)
   #:use-module (ice-9 match)
+  #:use-module (ice-9 pretty-print)
+  #:use-module (ice-9 rdelim)
 
   #:use-module (srfi srfi-1)
   #:use-module (srfi srfi-26)
@@ -30,19 +32,27 @@
 
   #:export (->
             <->
+            %debug?
             alist->hash-table
+            atom?
+            common-prefix
             conjoin
+            debug
             delete-adjacent-duplicates
             disjoin
             display-join
+            display-join*
             hash-table->alist
             json-string->alist-scm
             merge-alist2
             merge-alist-list
             pke
+            ppke
             seq
             singleton?
-            split-lists))
+            split-lists
+            write-line-error)
+  #:re-export (write-line))
 
 (define (disjoin . predicates)
   "Like OR but for predicates:
@@ -78,17 +88,13 @@ arguments:
   (lambda arguments
     (map (cute apply <> arguments) procedures)))
 
+(define (atom? o)
+  (and (not (pair? o))
+       (not (null? o))))
+
 (define (singleton? list)
   (and (= 1 (length list)) (car list)))
 
-(define (pke . stuff)
-  "Like peek (pk), writing to (CURRENT-ERROR-PORT)."
-  (newline (current-error-port))
-  (display ";;; " (current-error-port))
-  (write stuff (current-error-port))
-  (newline (current-error-port))
-  (car (last-pair stuff)))
-
 (define (alist->hash-table alist)
   (let ((table (make-hash-table (length alist))))
     (for-each (lambda (entry)
@@ -144,7 +150,10 @@ guile-json-4 (which produces vectors)."
                 (if (null? head) heads (cons head heads))
                 (if (null? tail) tails (cons tail tails)))))))
 
-(define (display-join lst port . grammar)
+(define* (display-join* lst #:key
+                        (port (current-output-port))
+                        (display-element (cute display <> <>))
+                        (grammar '()))
   "Like STRING-JOIN but displaying to PORT, also allowing \"PRE\" 'pre
 and \"POST\" 'post in GRAMMAR."
   (define (reduce-sexp l)
@@ -170,7 +179,7 @@ and \"POST\" 'post in GRAMMAR."
       (when (pair? lst)
         (when prefix
           (display prefix port))
-        (display (car lst) port)
+        (display-element (car lst) port)
         (when suffix
           (display suffix port))
         (when (and (pair? (cdr lst)) infix)
@@ -179,6 +188,9 @@ and \"POST\" 'post in GRAMMAR."
     (when (and post (pair? lst))
       (display post port))))
 
+(define (display-join lst port . grammar)
+  (display-join* lst #:port port #:grammar grammar))
+
 (define (delete-adjacent-duplicates lst =)
   "When LST is sorted all duplicates are adjacent one another.
 This procedure recursively drops an element from the list when it equals
@@ -191,3 +203,49 @@ the next element."
        (let ((tail (cons next rest)))
          (if (= head next) (loop tail)
              (cons head (loop tail))))))))
+
+(define* (common-prefix lst-a lst-b #:key (eq? eq?))
+  (if (or (null? lst-a) (null? lst-b)) '()
+      (let ((car-a lst-a (car+cdr lst-a))
+            (car-b lst-b (car+cdr lst-b)))
+        (if (not (eq? car-a car-b)) '()
+            (cons car-a (common-prefix lst-a lst-b #:eq? eq?))))))
+
+
+;;;
+;;; Debugging.
+;;;
+
+;; Should debug info be printed?
+(define %debug? (make-parameter #f))
+
+(define (pke . stuff)
+  "Like peek (pk), writing to (CURRENT-ERROR-PORT)."
+  (newline (current-error-port))
+  (display ";;; " (current-error-port))
+  (write stuff (current-error-port))
+  (newline (current-error-port))
+  (car (last-pair stuff)))
+
+(define (ppke . args)
+  "A pretty version of pke."
+  ;; FIXME printing goops
+  ;; (pretty-print args #:per-line-prefix ";;; ") should have been enough
+  ;; but printing the AST requires serializing and then reading it back as sexp
+  (define (pretty o)
+    (pretty-print
+     (call-with-input-string
+         (with-output-to-string (cute write o))
+       read)
+     (current-error-port)
+     #:per-line-prefix ";;; "))
+  (for-each pretty args)
+  (car (last-pair args)))
+
+(define (debug fmt . args)
+  (when (%debug?)
+    (apply format (current-error-port) fmt args)
+    (newline (current-error-port))))
+
+(define (write-line-error o)
+  (write-line o (current-error-port)))
