@@ -1,6 +1,6 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
-;;; Copyright © 2016, 2017, 2021, 2022 Rutger van Beusekom <rutger@dezyne.org>
+;;; Copyright © 2016, 2017, 2021, 2022, 2024 Rutger van Beusekom <rutger@dezyne.org>
 ;;; Copyright © 2019, 2020, 2021 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
 ;;;
 ;;; This file is part of Dezyne.
@@ -103,6 +103,13 @@ that the pipeline produced as a string, and a sum of the output stati of
 the pipeline COMMANDS."
   (define (pipeline-with-input commands input)
     (let ((output-port input-port pids (pipeline commands)))
+      (for-each
+       (lambda (signal)
+         (sigaction signal (lambda (flag)
+                             (map (cute kill <> signal) pids)
+                             (exit 1))))
+       `(,@(if (defined? 'SIGALRM) (list SIGALRM) '())
+         ,SIGINT))
       (display input output-port)
       (close output-port)
       (let ((stdout (read-string input-port)))
@@ -129,6 +136,13 @@ of the output stati of the pipeline COMMANDS."
   (define (pipeline-with-input commands input)
     (let ((output-port input-port pids
                        (pipeline commands #:output-port (current-output-port))))
+      (for-each
+       (lambda (signal)
+         (sigaction signal (lambda (flag)
+                             (map (cute kill <> signal) pids)
+                             (exit 1))))
+       `(,@(if (defined? 'SIGALRM) (list SIGALRM) '())
+         ,SIGINT))
       (display input output-port)
       (close output-port)
       (false-if-exception (close input-port))
