@@ -1,8 +1,8 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
-;;; Copyright © 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024 Janneke Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024, 2025 Janneke Nieuwenhuizen <janneke@gnu.org>
 ;;; Copyright © 2018 Rob Wieringa <rma.wieringa@gmail.com>
-;;; Copyright © 2022, 2023 Rutger (regtur) van Beusekom <rutger@dezyne.org>
+;;; Copyright © 2022, 2023, 2024 Rutger (regtur) van Beusekom <rutger@dezyne.org>
 ;;;
 ;;; This file is part of Dezyne.
 ;;;
@@ -35,7 +35,7 @@
   #:use-module (ice-9 match)
   #:use-module (ice-9 poe)
 
-  #:use-module (dzn ast goops)
+  #:use-module (dzn ast ast)
   #:use-module (dzn command-line)
   #:use-module (dzn misc)
   #:use-module (dzn shell-util)
@@ -53,14 +53,14 @@
 ;; the first entry also prints accumulated times.
 (define %time
   `(((dzn script) run-command)
-    ((dzn parse) file+import-content-alist)
-    ((dzn parse) file->ast)
-    ((dzn parse) file->stream)
-    ((dzn parse) string->ast)
+    ((dzn parse) parse:file->content-alist)
+    ((dzn parse) parse:string->content-alist)
+    ((dzn parse) parse:content-alist->tree-alist)
+    ((dzn parse) parse:tree-alist->ast)
+    ((dzn parse) parse:file->tree-alist+content-alist)
     ((dzn ast normalize) normalize:event+illegals)
     ((dzn ast normalize) normalize:state+illegals)
     ((dzn code) code:normalize)
-    ((dzn code) code:normalize+determinism)
     ((dzn code language c++) ast->)
     ((dzn code language makreel) makreel:normalize)
     ((dzn code scmackerel makreel) root->scmackerel)
@@ -69,9 +69,9 @@
 
 ;; Procedures to instrument with measure-duration.
 (define %measure
-  `(((dzn parse) parse-tree->ast)
-    ((dzn parse) string->parse-tree)
-    ((dzn code language makreel) root->)
+  `(((dzn parse) parse:file->string)
+    ((dzn parse) parse:string->tree)
+    ((dzn parse) parse:tree->ast)
     ((dzn ast accessor) ast:parent (,<ast> ,<class>))
     ((dzn ast lookup) ast:lookup (,<ast> ,<top>))
     ((dzn ast lookup) ast:lookup-variable (,<ast> ,<top>))))
@@ -83,16 +83,19 @@
             (repl (single-char #\R))
             (skip-wfc (single-char #\p))
             (timings (single-char #\T))
+            (threads (value #t))
             (transform (single-char #\t) (value #t))
             (verbose (single-char #\v))
-            (version (single-char #\V))))
+            (version (single-char #\V))
+            (version-number)))
          (options (getopt-long args option-spec
                                #:stop-at-first-non-option #t))
          (verbose? (option-ref options 'verbose #f))
          (help? (option-ref options 'help #f))
          (files (option-ref options '() '()))
          (usage? (and (not help?) (null? files)))
-         (version? (option-ref options 'version #f)))
+         (version? (option-ref options 'version #f))
+         (version-number? (option-ref options 'version-number #f)))
 
     (define (list-commands dir)
       (let* ((uninstalled? (getenv "DZN_UNINSTALLED"))
@@ -110,6 +113,8 @@
 
     (when version?
       (show-version-and-exit))
+    (when version-number?
+      (show-version-number-and-exit))
     (when (or help? usage?)
       (let* ((port (if usage? (current-error-port) (current-output-port)))
              (commands (list-commands "/dzn/commands/"))
@@ -143,6 +148,8 @@ Usage: dzn [OPTION]... COMMAND [COMMAND-ARGUMENT...]
   -V, --version          display version
   -t, --transform=TRANS  use transformation TRANS
   -T, --timings          show timings
+      --threads=N        invoke LTS2LPS with --threads=N
+
 
 Commands:~a
 
