@@ -1,6 +1,6 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
-;;; Copyright © 2019, 2020, 2021, 2022, 2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2019, 2020, 2021, 2022, 2023, 2024, 2025 Janneke Nieuwenhuizen <janneke@gnu.org>
 ;;; Copyright © 2020, 2021, 2022, 2023 Rutger van Beusekom <rutger@dezyne.org>
 ;;;
 ;;; This file is part of Dezyne.
@@ -29,7 +29,7 @@
   #:use-module (ice-9 rdelim)
 
   #:use-module (dzn ast display)
-  #:use-module (dzn ast goops)
+  #:use-module (dzn ast ast)
   #:use-module (dzn ast)
   #:use-module (dzn command-line)
   #:use-module (dzn config)
@@ -39,6 +39,7 @@
   #:use-module (dzn shell-util)
   #:use-module (dzn vm compliance)
   #:use-module (dzn vm goops)
+  #:use-module (dzn vm invariant)
   #:use-module (dzn vm normalize)
   #:use-module (dzn vm report)
   #:use-module (dzn vm run)
@@ -365,18 +366,24 @@ or false."
                                           #:input event)))
                             (%debug (current-source-location) "<match-error>: ~a" event)
                             (list (list (clone pc #:status error))))))
-              (traces (map (cute append <> pc+blocked-trace) traces)))
-         (if (is-a? (%sut) <runtime:port>) traces
-             (let* ((cpc (if (requires-trigger? event) pc
-                             (last pc+blocked-trace)))
-                    (cpc (reset-replies cpc))
-                    (cpc (clone cpc #:instance #f)))
-               (check-provides-compliance* cpc event traces)))))
+              (traces (map (cute append <> pc+blocked-trace) traces))
+              (traces (if (is-a? (%sut) <runtime:port>) traces
+                          (let* ((cpc (if (requires-trigger? event) pc
+                                          (last pc+blocked-trace)))
+                                 (cpc (reset-replies cpc))
+                                 (cpc (clone cpc #:instance #f)))
+                            (check-provides-compliance* cpc event traces))))
+              (invariants (append-map check-invariants traces)))
+         (if (pair? invariants) invariants
+             traces)))
       ((? (const (and (pair? (.defer pc)) (not (%strict?)))))
        (let* ((traces (flush-defer pc))
               (traces (if (null? blocked-trace) traces
-                          (extend-trace blocked-trace (const traces)))))
-         (check-provides-compliance* pc event traces)))
+                          (extend-trace blocked-trace (const traces))))
+              (traces (check-provides-compliance* pc event traces))
+              (invariants (append-map check-invariants traces)))
+         (if (pair? invariants) invariants
+             traces)))
       (_
        (when (not (eq? (switch-context pc) pc))
          (%debug (current-source-location) "<eot> with switchable, non-rtc pc"))
@@ -640,35 +647,35 @@ status."
         (and queue-full-check?
              (not (is-a? (%sut) <runtime:port>))
              (and=> (check-external-queue-full traces)
-                    (cute report <>
-                          #:eligible '()
-                          #:internal? internal?
-                          #:locations? locations?
-                          #:state? state?
-                          #:trace trace
-                          #:verbose? verbose?)))
+                    (cut report <>
+                         #:eligible '()
+                         #:internal? internal?
+                         #:locations? locations?
+                         #:state? state?
+                         #:trace trace
+                         #:verbose? verbose?)))
         (and interface-determinism-check?
              (not status)
              (is-a? (%sut) <runtime:port>)
              (and=> (check-interface-determinism traces)
-                    (cute report <>
-                          #:eligible '()
-                          #:internal? internal?
-                          #:locations? locations?
-                          #:state? state?
-                          #:trace trace
-                          #:verbose? verbose?)))
+                    (cut report <>
+                         #:eligible '()
+                         #:internal? internal?
+                         #:locations? locations?
+                         #:state? state?
+                         #:trace trace
+                         #:verbose? verbose?)))
         (and interface-livelock-check?
              (not status)
              (is-a? (%sut) <runtime:port>)
              (and=> (check-interface-livelock traces)
-                    (cute report <>
-                          #:eligible '()
-                          #:internal? internal?
-                          #:locations? locations?
-                          #:state? state?
-                          #:trace trace
-                          #:verbose? verbose?)))
+                    (cut report <>
+                         #:eligible '()
+                         #:internal? internal?
+                         #:locations? locations?
+                         #:state? state?
+                         #:trace trace
+                         #:verbose? verbose?)))
         (and refusals-check? (null? traces)
              (any (cute refusals-report from-pcs <> '()) from-pcs))
         (and refusals-check? (pair? traces)
@@ -745,6 +752,9 @@ status."
       (serialize-header (.state pc) (current-output-port))
       (newline))
     (or (report (list (list pc)) #:trace trace)
+        (match (check-invariants (list pc))
+          ((traces ..1) (report traces #:trace trace))
+          (_ #f))
         (parameterize ((%next-input (if (or (not (isatty? (current-input-port))) (pair? trail)) trail-input read-input)))
           (let loop ((traces (list (list pc))))
             (%debug (current-source-location) "run-trail #traces ~a" (length traces))
@@ -909,7 +919,7 @@ status."
          (file-name (search-path
                      (cons "." (find-files (string-append %test-dir "/all") #:directories? #t))
                      file-name))
-         (root (file->ast file-name))
+         (root (parse:file->ast file-name))
          (root (vm:normalize root)))
     (%sut (runtime:get-sut root (ast:get-model root model-name)))
     (%instances (runtime:create-instances (%sut)))
@@ -1024,6 +1034,10 @@ memoizations to work."
                  (%queue-size-external queue-size-external)
                  (%strict? strict?)
                  (%sut sut))
+    (when (%debug?)
+      (%debug "sut: ~a\n" sut)
+      (%debug "instances\n")
+      (for-each (cute write-line <> (current-error-port)) instances))
     (run-trail trail
                #:deadlock-check? deadlock-check?
                #:interface-determinism-check? interface-determinism-check?
