@@ -1,7 +1,7 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
-;;; Copyright © 2019, 2020, 2021, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
-;;; Copyright © 2020, 2021 Rutger van Beusekom <rutger@dezyne.org>
+;;; Copyright © 2019, 2020, 2021, 2022, 2023, 2025 Janneke Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2020, 2021, 2022, 2024 Rutger (regtur) van Beusekom <rutger@dezyne.org>
 ;;;
 ;;; This file is part of Dezyne.
 ;;;
@@ -29,11 +29,12 @@
   #:use-module (ice-9 curried-definitions)
   #:use-module (ice-9 match)
 
-  #:use-module (dzn ast goops)
+  #:use-module (dzn ast ast)
   #:use-module (dzn ast normalize)
   #:use-module (dzn ast)
   #:use-module (dzn misc)
   #:use-module (dzn vm goops)
+  #:use-module (dzn vm invariant)
   #:export (vm:normalize
             normalize:compounds))
 
@@ -187,18 +188,40 @@
     ((? (is? <ast>)) (tree-map transform-end-of-on o))
     (_ o)))
 
+(define (lift-invariants o)
+  (match o
+    (($ <behavior>)
+     (let* ((compound (.statement o))
+            (invariants (tree-collect (is? <invariant>) compound))
+            (invariants (map invariant:include-guard-expressions invariants))
+            (compound (remove-invariant compound))
+            (elements (append invariants
+                              (.elements compound))))
+       (clone o #:statement (clone compound #:elements elements))))
+    (($ <interface>)
+     (clone o #:behavior (lift-invariants (.behavior o))))
+    (($ <component>)
+     (clone o #:behavior (lift-invariants (.behavior o))))
+    (($ <system>)
+     o)
+    ((? (is? <ast>)) (tree-map lift-invariants o))
+    (_ o)))
+
 
 ;;;
 ;;; Entry point: normalize.
 ;;;
 
 (define (vm:normalize root)
+  "Normalizations for the simulator: purge-data, add-explicit-temporaries, annotate-otherwise, transform-end-of-on, set-blocking-reply-port, add-function-return, normalize:compounds."
   ((compose
     (cut normalize:compounds <> #:wrap-imperative? #t)
     add-function-return
     set-blocking-reply-port
     transform-end-of-on
     (annotate-otherwise)
-    add-explicit-temporaries
-    purge-data)
+    lift-invariants
+    inline-expression-functions
+    purge-data
+    (add-explicit-temporaries))
    root))
