@@ -1,7 +1,7 @@
 // Dezyne --- Dezyne command line tools
 //
 // Copyright © 2018 Filip Toman <filip.toman@verum.com>
-// Copyright © 2021 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+// Copyright © 2021, 2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
 //
 // This file is part of Dezyne.
 //
@@ -25,21 +25,23 @@
 #include <hello.h>
 
 /* call "name-of-foreign"_skel_init as follows:
-   foreign_skel_init(&(self->base), dezyne_locator, dzn_meta); */
+   foreign_skel_init(&(self->base), dzn_locator, dzn_meta); */
 
-void library_foreign_init(library_foreign* self, locator* dezyne_locator
-#if DZN_TRACING
-                  , dzn_meta* dzn_meta
+void
+library_foreign_init (library_foreign *self, dzn_locator *dzn_locator
+#if 1 //DZN_TRACING
+                      , dzn_meta *dzn_meta
 #endif /* !DZN_TRACING */
-)
+                     )
 {
-  library_foreign_skel_init(&(self->base), dezyne_locator
-#if DZN_TRACING
-                    , dzn_meta
+  library_foreign_skel_init (& (self->base), dzn_locator
+#if 1 //DZN_TRACING
+                             , dzn_meta
 #endif /* !DZN_TRACING */
-                    );
+                            );
 }
 
-void library_foreign_w_world(library_foreign* self)
+void
+library_foreign_w_world (library_foreign *self)
 {
 }
