@@ -43,6 +43,9 @@
   #:export (%default-stages
             get-meta-option
             run-baseline
+            run-baseline
+            run-build
+            run-execute
             run-test))
 
 (define %default-stages
@@ -267,6 +270,9 @@ output, and standard error as three values."
                     (feature? "flush"))
                 "flush")
            (feature? "inject")
+           (and (or (feature? "reply_data")
+                    (feature? "data_reply"))
+                "reply-data")
            (feature? "shared")
            (or (feature? "shell")
                (and (thread-safe-shell? file-name)
@@ -348,7 +354,7 @@ output, and standard error as three values."
                 ,dzn-name)
               `("dzn" "--verbose" "verify"
                 ,@includes
-                "--all"
+                "--keep-going"
                 ,@(if (not no-unreachable?) '()
                       `("--no-unreachable"))
                 ,@(if (not queue-size) '()
@@ -679,12 +685,14 @@ are weak-bisim equivalent"
           (and (zero? status)
                (let* ((meta? (member language '("c++")))
                       (net (trace:format-trace stderr #:format "event" #:meta? meta?))
-                      (net (filter-<defer> net))
+                      (net (if meta? net
+                               (filter-<defer> net)))
                       (net (if meta? net
                                (filter-<flush> net))))
                  (receive (status stdout stderr)
                      (let* ((input (filter-state input))
-                            (input (filter-<defer> input))
+                            (input (if meta? input
+                                       (filter-<defer> input)))
                             (input (if meta? input
                                        (filter-<flush> input))))
                        (observe `("bash" "-c"
